PyPI - the Python Package Index : Python Package Index

#

#### Not Logged In

- Login
- Register
- Lost Login?
- Use OpenID

# PyPI - the Python Package Index

The Python Package Index is a repository of software for the Python programming language. There are currently 52436 packages here.
To contact the PyPI admins, please use the Support or Bug reports links.

Get Packages

To use a package from this index either "pip install package" (get pip) or download, unpack and "python setup.py install" it.

Package Authors

Submit packages with "python setup.py upload". The index hosts package docs. You may also use the web form. You must register. Testing? Use testpypi.

Infrastructure

To interoperate with the index use the JSON, OAuth, XML-RPC or HTTP interfaces. Use local mirroring or caching to make installation more robust.

Updated | Package | Description
--- | --- | ---
2014-12-06 | misfit 0.0.1 | Misfit API client implementation
2014-12-06 | limnoria 2014.11.24 | A modified version of Supybot (an IRC bot and framework)
2014-12-06 | droneapi 1.0.1 | Python language bindings for the DroneApi
2014-12-06 | guv 0.33.2 | Python 3 networking library based on greenlets and libuv
2014-12-06 | peep 2.0 | A "pip install" that is cryptographically guaranteed repeatable
2014-12-05 | responsys 0.1.11-alpha | Python client library for the Responsys Interact API
2014-12-05 | dj-utils 0.1.6 | Django utilities.
2014-12-05 | braincore 2014.12.5 | Core objects needed for most brainfuck-like languages
2014-12-05 | dockerup 1.0.0 | Docker container manager
2014-12-05 | python3_riak_pb 2.0.0.16 | Riak Protocol Buffers Messages
2014-12-05 | youtube_dl 2014.12.06.1 | YouTube video downloader
2014-12-05 | ppp_datamodel 0.5.19 | Data model for the Projet Pensées Profondes.
2014-12-05 | Flask-DebugToolbar 0.9.2 | A port of the Django debug toolbar to Flask
2014-12-05 | bugsy 0.4.0 | A library for interacting Bugzilla Native REST API
2014-12-05 | keen 0.3.6 | Python Client for Keen IO
2014-12-05 | multipla 0.2.0 | Plugin handling system
2014-12-05 | PyBinder 1.3.1 | Python dependency injection and management tool
2014-12-05 | django-selenium-boilerplate 0.0.6 | Boilerplate for setting up selenium tests in Django
2014-12-05 | rdbms-subsetter 0.2.0 | Generate consistent subset of an RDBMS
2014-12-05 | kegmeter-app 0.99.4 | Kegmeter libraries used by both the app and the webserver
2014-12-05 | django-fobi 0.4.4 | Customisable, modular user- and developer- friendly form generator/builder application for Django
2014-12-05 | ethereum-serpent 1.7.7 | Serpent compiler
2014-12-05 | pynt-of-django 0.1.0 |
2014-12-05 | railroadtracks 0.3.1 | Framework to connect computional steps with an emphasis on RNA-Seq
2014-12-05 | bokeh 0.7.0 | Statistical and novel interactive HTML plots for Python
2014-12-05 | clc-cli 0.6 | CenturyLink Cloud CLI
2014-12-05 | sloth-ci.ext.logs 1.0.7 | Logs for Sloth CI apps
2014-12-05 | pelican-readtime 0.1.1 | Plugin for Pelican that computes read time based on Medium's readtime "algorithm."
2014-12-05 | Fortpy 1.3.1 | Fortran Parsing, Unit Testing and Intellisense
2014-12-05 | sloth-ci 1.0.8 | Simple app for automatization of everything
2014-12-05 | britney 0.4.0 | Python implementation of SPORE
2014-12-05 | tornadwwo 0.1 | Async API calls for World Weather Online
2014-12-05 | marketplace-env 0.1.6.3 | Tools for building the Firefox Marketplace using Docker.
2014-12-05 | logex 1.0.0 | Easily log uncaught exceptions in D-Bus, thread and other functions.
2014-12-05 | GoogleAppEnginePipeline 1.9.15.1 | Enable asynchronous pipeline style data processing on App Engine
2014-12-05 | pypdfocr 0.8.1 | Converts a scanned PDF into an OCR'ed pdf using Tesseract-OCR and Ghostscript
2014-12-05 | google_speech 1.0.2 | Read text using Google voice
2014-12-05 | python-rightscale 0.1.2 | Python wrapper for the Rightscale API
2014-12-05 | afapi 1.0.3 | A Python wrapper for interacting with AppFirst's APIs (v5) See https://github.com/appfirst/afapi for more info.
2014-12-05 | nanoservice 0.1.6 | nanoservice is a small Python library for writing lightweight networked services using nanomsg

And now for something completely different...

Customer: Now then, some cheese please, my good man.
Owner: (lustily) Certainly, sir. What would you like?
Customer: Well, eh, how about a little red Leicester.
Owner: I'm, a-fraid we're fresh out of red Leicester, sir.